timespantools.offset_happens_before_timespan_starts
===================================================

.. autofunction:: abjad.tools.timespantools.offset_happens_before_timespan_starts.offset_happens_before_timespan_starts
